import numpy
import math
from lib6003.image import *

def circle_filter(size, cutoff=numpy.pi/2):
    """
    parameters:
      size: the number of rows (and columns) in the image we want to filter.
      cutoff: a number representing the highest Omega value that should be
              passed.

    returns:
      the DFT coefficients associated with a filter whose frequency response is
      a solid circle (frequencies below the given cutoff are passed, and
      frequencies above are zeroed out).
    """
    circle = numpy.zeros((size, size), dtype=float)
    for kr in range(-(size//2), size//2+1):
        for kc in range(-(size//2), size//2+1):
            if (kr**2 + kc**2)**0.5 < cutoff/numpy.pi*(size/2):
                circle[kr, kc] = 1
    return circle


def gauss_1d(x, sigma=1, mu=0, norm=True):
    """
    helper: sample a 1D gaussian at a given point.
    """
    val = 1 / (sigma * math.sqrt(2*math.pi)) * math.e**(-1/2 * ((x - mu)/sigma)**2)
    if norm:
        z = gauss_1d(mu, sigma, mu, norm=False)
    else:
        z = 1
    return val / z


def gauss_filter(size, sigma=100):
    """
    parameters:
      size: the number of rows (and columns) in the image we want to filter.
      sigma: the standard deviation of the 2D Gaussian (in frequency)

    returns:
      the DFT coefficients associated with a filter whose frequency response is
      a 2D Gaussian centered on (kr=0, kc=0)
    """
    gauss = numpy.zeros((size, size), dtype=float)
    for kr in range(-(size//2), size//2+1):
        for kc in range(-(size//2), size//2+1):
            gauss[kr, kc] = gauss_1d((kr**2 + kc**2)**0.5, sigma, norm=True)
    return gauss
